@@ -1,4 +1,6 @@
-__version__ = "0.8.3a"
+import warnings
+
+__version__ = "0.8.9a"
 __author__ = "Anoop Thomas Mathew"
 __license__ = "BSD"
 __contact__ = "atmb4u at gmail dot com"
@@ -20,7 +22,7 @@ class Butler(object):
         >>> data1.get(["key"])
         'value'
         >>> data2 = Butler([1, 2, 4, 5, [10, 20, 30, 40, 50]])
-        >>> data2.get([4, 3])
+        >>> data2.__getitem__([4, 3])
         40
         >>> data2.get([4, 9])
 
@@ -36,7 +38,7 @@ class Butler(object):
                 return None
         return return_obj
 
-    def get(self, path):
+    def get(self, path, default=None):
         """
         Grab values inside nested dict and list if available, else returns None
         Returns None if looking up in string.
@@ -52,11 +54,16 @@ class Butler(object):
         >>> data3 = Butler("Hello world")
         >>> data3.get([6])
 
+        >>> data2.get([4, 10], default="BLANK")
+        'BLANK'
+        >>> data2.get([4, 42], 0)
+        0
         """
         try:
             return self[path]
         except (LookupError, TypeError):
-            return None
+            warnings.warn("Could not find the requested element", UserWarning)
+            return default
 
     def path_exists(self, path):
         """
@@ -87,7 +94,7 @@ class Butler(object):
         >>> quick = Butler(data)
 
         >>> quick.flatten(data)
-        [('a', 10), ('c', 11), ('d', 13), ('e', 15), ('d', 14), ('b', [{'c': 11, 'd': 13}, {'e': 15, 'd': 14}])]
+        [('a', 10), ('b', [{'c': 11, 'd': 13}, {'e': 15, 'd': 14}]), (0, {'c': 11, 'd': 13}), ('c', 11), ('d', 13), (1, {'e': 15, 'd': 14}), ('e', 15), ('d', 14)]
         """
         if not sub_dict:
             sub_dict = self.obj
@@ -103,7 +110,6 @@ class Butler(object):
             output.append(key)
         return output
 
-
     def flatten(self, sub_dict=None, output=None):
         """
         TODO: Make use of generators
@@ -114,20 +120,20 @@ class Butler(object):
         >>> quick = Butler(data)
 
         >>> quick.flatten(data)
-        [('a', 10), ('c', 11), ('d', 13), ('e', 15), ('d', 14), ('b', [{'c': 11, 'd': 13}, {'e': 15, 'd': 14}])]
+        [('a', 10), ('b', [{'c': 11, 'd': 13}, {'e': 15, 'd': 14}]), (0, {'c': 11, 'd': 13}), ('c', 11), ('d', 13), (1, {'e': 15, 'd': 14}), ('e', 15), ('d', 14)]
         """
         if not sub_dict:
             sub_dict = self.obj
         if not output:
             output = []
-        for key in sub_dict:
-            if isinstance(sub_dict[key], dict):
+        if isinstance(sub_dict, dict):
+            for key in sub_dict:
+                output.append((key, sub_dict[key],))
                 self.flatten(sub_dict[key], output)
-            if isinstance(sub_dict[key], list):
-                for sub_dic in sub_dict[key]:
-                    if isinstance(sub_dic, dict):
-                        self.flatten(sub_dic, output)
-            output.append((key, sub_dict[key],))
+        elif isinstance(sub_dict, list):
+            for order, element in enumerate(sub_dict):
+                output.append((order, element,))
+                self.flatten(element, output)
         return output
 
     def findall(self, key, find=False):
@@ -148,20 +154,17 @@ class Butler(object):
 
         >>> quick1.findall(5)
         [5]
+        >>> Butler([{42: 'nope'}]).findall(42)
+        ['nope']
         """
         return_list = []
-        if isinstance(self.obj, dict):
+        if isinstance(self.obj, dict) or isinstance(self.obj, list):
             flat_list = self.flatten(self.obj)
             for item_key, data in flat_list:
                 if item_key == key:
                     if find:  # API for find() to return the first result
                         return data
                     return_list.append(data)
-        elif isinstance(self.obj, list):  # kept this to keep the API consistent across list and dict
-            if len(self.obj) > key:
-                if find:  # API for find() to return the first result
-                    return self.obj[key]
-                return_list.append(self.obj[key])
         else:
             print("findall can be used only with dict or list objects")
         return return_list
@@ -216,4 +219,4 @@ class Butler(object):
         if key in self.key_list(self.obj):
             return True
         else:
-            return False
\ No newline at end of file
+            return False
